"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.card.v1.common_pb2
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TopicCardType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopicCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopicCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ILLEGAL_TYPE: _TopicCardType.ValueType  # 0
    """"""
    DYNAMIC: _TopicCardType.ValueType  # 1
    """"""
    FOLD: _TopicCardType.ValueType  # 2
    """"""
    VIDEO_SMALL_CARD: _TopicCardType.ValueType  # 3
    """"""

class TopicCardType(_TopicCardType, metaclass=_TopicCardTypeEnumTypeWrapper):
    """"""

ILLEGAL_TYPE: TopicCardType.ValueType  # 0
""""""
DYNAMIC: TopicCardType.ValueType  # 1
""""""
FOLD: TopicCardType.ValueType  # 2
""""""
VIDEO_SMALL_CARD: TopicCardType.ValueType  # 3
""""""
global___TopicCardType = TopicCardType

class _TopicDetailsExtMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopicDetailsExtModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopicDetailsExtMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODE_ILLEGAL_TYPE: _TopicDetailsExtMode.ValueType  # 0
    """"""
    STORY: _TopicDetailsExtMode.ValueType  # 1
    """"""

class TopicDetailsExtMode(_TopicDetailsExtMode, metaclass=_TopicDetailsExtModeEnumTypeWrapper):
    """"""

MODE_ILLEGAL_TYPE: TopicDetailsExtMode.ValueType  # 0
""""""
STORY: TopicDetailsExtMode.ValueType  # 1
""""""
global___TopicDetailsExtMode = TopicDetailsExtMode

@typing_extensions.final
class ButtonMeta(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text"]) -> None: ...

global___ButtonMeta = ButtonMeta

@typing_extensions.final
class DetailsTopInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_INFO_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    STATS_DESC_FIELD_NUMBER: builtins.int
    HAS_CREATE_JURISDICTION_FIELD_NUMBER: builtins.int
    OPERATION_CONTENT_FIELD_NUMBER: builtins.int
    HEAD_IMG_URL_FIELD_NUMBER: builtins.int
    HEAD_IMG_BACKCOLOR_FIELD_NUMBER: builtins.int
    WORD_COLOR_FIELD_NUMBER: builtins.int
    MISSION_PAGE_SHOW_TYPE_FIELD_NUMBER: builtins.int
    MISSION_URL_FIELD_NUMBER: builtins.int
    MISSION_TEXT_FIELD_NUMBER: builtins.int
    TOPIC_SET_FIELD_NUMBER: builtins.int
    @property
    def topic_info(self) -> global___TopicInfo:
        """"""
    @property
    def user(self) -> global___User:
        """"""
    stats_desc: builtins.str
    """"""
    has_create_jurisdiction: builtins.bool
    """"""
    @property
    def operation_content(self) -> global___OperationContent:
        """"""
    head_img_url: builtins.str
    """"""
    head_img_backcolor: builtins.str
    """"""
    word_color: builtins.int
    """"""
    mission_page_show_type: builtins.int
    """"""
    mission_url: builtins.str
    """"""
    mission_text: builtins.str
    """"""
    @property
    def topic_set(self) -> global___TopicSet:
        """"""
    def __init__(
        self,
        *,
        topic_info: global___TopicInfo | None = ...,
        user: global___User | None = ...,
        stats_desc: builtins.str = ...,
        has_create_jurisdiction: builtins.bool = ...,
        operation_content: global___OperationContent | None = ...,
        head_img_url: builtins.str = ...,
        head_img_backcolor: builtins.str = ...,
        word_color: builtins.int = ...,
        mission_page_show_type: builtins.int = ...,
        mission_url: builtins.str = ...,
        mission_text: builtins.str = ...,
        topic_set: global___TopicSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_content", b"operation_content", "topic_info", b"topic_info", "topic_set", b"topic_set", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_create_jurisdiction", b"has_create_jurisdiction", "head_img_backcolor", b"head_img_backcolor", "head_img_url", b"head_img_url", "mission_page_show_type", b"mission_page_show_type", "mission_text", b"mission_text", "mission_url", b"mission_url", "operation_content", b"operation_content", "stats_desc", b"stats_desc", "topic_info", b"topic_info", "topic_set", b"topic_set", "user", b"user", "word_color", b"word_color"]) -> None: ...

global___DetailsTopInfo = DetailsTopInfo

@typing_extensions.final
class FoldCardItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SHOW_FOLD_FIELD_NUMBER: builtins.int
    FOLD_COUNT_FIELD_NUMBER: builtins.int
    CARD_SHOW_DESC_FIELD_NUMBER: builtins.int
    FOLD_DESC_FIELD_NUMBER: builtins.int
    is_show_fold: builtins.int
    """"""
    fold_count: builtins.int
    """"""
    card_show_desc: builtins.str
    """"""
    fold_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        is_show_fold: builtins.int = ...,
        fold_count: builtins.int = ...,
        card_show_desc: builtins.str = ...,
        fold_desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_show_desc", b"card_show_desc", "fold_count", b"fold_count", "fold_desc", b"fold_desc", "is_show_fold", b"is_show_fold"]) -> None: ...

global___FoldCardItem = FoldCardItem

@typing_extensions.final
class FunctionalCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPSULES_FIELD_NUMBER: builtins.int
    TRAFFIC_CARD_FIELD_NUMBER: builtins.int
    GAME_CARD_FIELD_NUMBER: builtins.int
    @property
    def capsules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicCapsule]:
        """"""
    @property
    def traffic_card(self) -> global___TrafficCard:
        """"""
    @property
    def game_card(self) -> global___GameCard:
        """"""
    def __init__(
        self,
        *,
        capsules: collections.abc.Iterable[global___TopicCapsule] | None = ...,
        traffic_card: global___TrafficCard | None = ...,
        game_card: global___GameCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["game_card", b"game_card", "traffic_card", b"traffic_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capsules", b"capsules", "game_card", b"game_card", "traffic_card", b"traffic_card"]) -> None: ...

global___FunctionalCard = FunctionalCard

@typing_extensions.final
class GameCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAME_ID_FIELD_NUMBER: builtins.int
    GAME_ICON_FIELD_NUMBER: builtins.int
    GAME_NAME_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    GAME_TAGS_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    GAME_LINK_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """"""
    game_icon: builtins.str
    """"""
    game_name: builtins.str
    """"""
    score: builtins.str
    """"""
    game_tags: builtins.str
    """"""
    notice: builtins.str
    """"""
    game_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        game_id: builtins.int = ...,
        game_icon: builtins.str = ...,
        game_name: builtins.str = ...,
        score: builtins.str = ...,
        game_tags: builtins.str = ...,
        notice: builtins.str = ...,
        game_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_icon", b"game_icon", "game_id", b"game_id", "game_link", b"game_link", "game_name", b"game_name", "game_tags", b"game_tags", "notice", b"notice", "score", b"score"]) -> None: ...

global___GameCard = GameCard

@typing_extensions.final
class InlineProgressBar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_DRAG_FIELD_NUMBER: builtins.int
    ICON_DRAG_HASH_FIELD_NUMBER: builtins.int
    ICON_STOP_FIELD_NUMBER: builtins.int
    ICON_STOP_HASH_FIELD_NUMBER: builtins.int
    icon_drag: builtins.str
    """"""
    icon_drag_hash: builtins.str
    """"""
    icon_stop: builtins.str
    """"""
    icon_stop_hash: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_drag: builtins.str = ...,
        icon_drag_hash: builtins.str = ...,
        icon_stop: builtins.str = ...,
        icon_stop_hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_drag", b"icon_drag", "icon_drag_hash", b"icon_drag_hash", "icon_stop", b"icon_stop", "icon_stop_hash", b"icon_stop_hash"]) -> None: ...

global___InlineProgressBar = InlineProgressBar

@typing_extensions.final
class LargeCoverInline(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON2_FIELD_NUMBER: builtins.int
    RIGHT_TOP_LIVE_BADGE_FIELD_NUMBER: builtins.int
    EXTRA_URI_FIELD_NUMBER: builtins.int
    INLINE_PROGRESS_BAR_FIELD_NUMBER: builtins.int
    TOPIC_THREE_POINT_FIELD_NUMBER: builtins.int
    COVER_LEFT_DESC_FIELD_NUMBER: builtins.int
    HIDE_DANMU_SWITCH_FIELD_NUMBER: builtins.int
    DISABLE_DANMU_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    DURATION_TEXT_FIELD_NUMBER: builtins.int
    RELATION_DATA_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_text1: builtins.str
    """"""
    cover_left_icon1: builtins.int
    """"""
    cover_left_text2: builtins.str
    """"""
    cover_left_icon2: builtins.int
    """"""
    @property
    def right_top_live_badge(self) -> global___RightTopLiveBadge:
        """"""
    extra_uri: builtins.str
    """"""
    @property
    def inline_progress_bar(self) -> global___InlineProgressBar:
        """"""
    @property
    def topic_three_point(self) -> global___TopicThreePoint:
        """"""
    cover_left_desc: builtins.str
    """"""
    hide_danmu_switch: builtins.bool
    """"""
    disable_danmu: builtins.bool
    """"""
    can_play: builtins.int
    """"""
    duration_text: builtins.str
    """"""
    @property
    def relation_data(self) -> global___RelationData:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_text1: builtins.str = ...,
        cover_left_icon1: builtins.int = ...,
        cover_left_text2: builtins.str = ...,
        cover_left_icon2: builtins.int = ...,
        right_top_live_badge: global___RightTopLiveBadge | None = ...,
        extra_uri: builtins.str = ...,
        inline_progress_bar: global___InlineProgressBar | None = ...,
        topic_three_point: global___TopicThreePoint | None = ...,
        cover_left_desc: builtins.str = ...,
        hide_danmu_switch: builtins.bool = ...,
        disable_danmu: builtins.bool = ...,
        can_play: builtins.int = ...,
        duration_text: builtins.str = ...,
        relation_data: global___RelationData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "inline_progress_bar", b"inline_progress_bar", "relation_data", b"relation_data", "right_top_live_badge", b"right_top_live_badge", "topic_three_point", b"topic_three_point"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "can_play", b"can_play", "cover_left_desc", b"cover_left_desc", "cover_left_icon1", b"cover_left_icon1", "cover_left_icon2", b"cover_left_icon2", "cover_left_text1", b"cover_left_text1", "cover_left_text2", b"cover_left_text2", "disable_danmu", b"disable_danmu", "duration_text", b"duration_text", "extra_uri", b"extra_uri", "hide_danmu_switch", b"hide_danmu_switch", "inline_progress_bar", b"inline_progress_bar", "relation_data", b"relation_data", "right_top_live_badge", b"right_top_live_badge", "topic_three_point", b"topic_three_point"]) -> None: ...

global___LargeCoverInline = LargeCoverInline

@typing_extensions.final
class LiveBadgeResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ANIMATION_URL_FIELD_NUMBER: builtins.int
    ANIMATION_URL_HASH_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_LIGHT_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    ALPHA_LIGHT_FIELD_NUMBER: builtins.int
    ALPHA_NIGHT_FIELD_NUMBER: builtins.int
    FONT_COLOR_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    animation_url: builtins.str
    """"""
    animation_url_hash: builtins.str
    """"""
    background_color_light: builtins.str
    """"""
    background_color_night: builtins.str
    """"""
    alpha_light: builtins.int
    """"""
    alpha_night: builtins.int
    """"""
    font_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        animation_url: builtins.str = ...,
        animation_url_hash: builtins.str = ...,
        background_color_light: builtins.str = ...,
        background_color_night: builtins.str = ...,
        alpha_light: builtins.int = ...,
        alpha_night: builtins.int = ...,
        font_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alpha_light", b"alpha_light", "alpha_night", b"alpha_night", "animation_url", b"animation_url", "animation_url_hash", b"animation_url_hash", "background_color_light", b"background_color_light", "background_color_night", b"background_color_night", "font_color", b"font_color", "text", b"text"]) -> None: ...

global___LiveBadgeResource = LiveBadgeResource

@typing_extensions.final
class OperationCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LARGE_COVER_INLINE_FIELD_NUMBER: builtins.int
    @property
    def large_cover_inline(self) -> global___LargeCoverInline:
        """"""
    def __init__(
        self,
        *,
        large_cover_inline: global___LargeCoverInline | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card", b"card", "large_cover_inline", b"large_cover_inline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card", b"card", "large_cover_inline", b"large_cover_inline"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card", b"card"]) -> typing_extensions.Literal["large_cover_inline"] | None: ...

global___OperationCard = OperationCard

@typing_extensions.final
class OperationContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_CARD_FIELD_NUMBER: builtins.int
    @property
    def operation_card(self) -> global___OperationCard:
        """"""
    def __init__(
        self,
        *,
        operation_card: global___OperationCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_card", b"operation_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation_card", b"operation_card"]) -> None: ...

global___OperationContent = OperationContent

@typing_extensions.final
class PubLayer(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_TYPE_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    BUTTON_META_FIELD_NUMBER: builtins.int
    CLOSE_PUB_LAYER_ENTRY_FIELD_NUMBER: builtins.int
    show_type: builtins.int
    """"""
    jump_link: builtins.str
    """"""
    @property
    def button_meta(self) -> global___ButtonMeta:
        """"""
    close_pub_layer_entry: builtins.bool
    """"""
    def __init__(
        self,
        *,
        show_type: builtins.int = ...,
        jump_link: builtins.str = ...,
        button_meta: global___ButtonMeta | None = ...,
        close_pub_layer_entry: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button_meta", b"button_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_meta", b"button_meta", "close_pub_layer_entry", b"close_pub_layer_entry", "jump_link", b"jump_link", "show_type", b"show_type"]) -> None: ...

global___PubLayer = PubLayer

@typing_extensions.final
class RelationData(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_FAV_FIELD_NUMBER: builtins.int
    IS_COIN_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    LIKE_COUNT_FIELD_NUMBER: builtins.int
    is_fav: builtins.bool
    """"""
    is_coin: builtins.bool
    """"""
    is_follow: builtins.bool
    """"""
    is_like: builtins.bool
    """"""
    like_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        is_fav: builtins.bool = ...,
        is_coin: builtins.bool = ...,
        is_follow: builtins.bool = ...,
        is_like: builtins.bool = ...,
        like_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_coin", b"is_coin", "is_fav", b"is_fav", "is_follow", b"is_follow", "is_like", b"is_like", "like_count", b"like_count"]) -> None: ...

global___RelationData = RelationData

@typing_extensions.final
class RightTopLiveBadge(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_STATUS_FIELD_NUMBER: builtins.int
    IN_LIVE_FIELD_NUMBER: builtins.int
    LIVE_STATS_DESC_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """"""
    @property
    def in_live(self) -> global___LiveBadgeResource:
        """"""
    live_stats_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        live_status: builtins.int = ...,
        in_live: global___LiveBadgeResource | None = ...,
        live_stats_desc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_live", b"in_live"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["in_live", b"in_live", "live_stats_desc", b"live_stats_desc", "live_status", b"live_status"]) -> None: ...

global___RightTopLiveBadge = RightTopLiveBadge

@typing_extensions.final
class SortContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_BY_FIELD_NUMBER: builtins.int
    SORT_NAME_FIELD_NUMBER: builtins.int
    sort_by: builtins.int
    """"""
    sort_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        sort_by: builtins.int = ...,
        sort_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_by", b"sort_by", "sort_name", b"sort_name"]) -> None: ...

global___SortContent = SortContent

@typing_extensions.final
class ThreePointItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jump_url", b"jump_url", "title", b"title"]) -> None: ...

global___ThreePointItem = ThreePointItem

@typing_extensions.final
class TimeLineEvents(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TIME_DESC_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    event_id: builtins.int
    """"""
    title: builtins.str
    """"""
    time_desc: builtins.str
    """"""
    jump_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        event_id: builtins.int = ...,
        title: builtins.str = ...,
        time_desc: builtins.str = ...,
        jump_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_id", b"event_id", "jump_link", b"jump_link", "time_desc", b"time_desc", "title", b"title"]) -> None: ...

global___TimeLineEvents = TimeLineEvents

@typing_extensions.final
class TimeLineResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_LINE_ID_FIELD_NUMBER: builtins.int
    TIME_LINE_TITLE_FIELD_NUMBER: builtins.int
    TIME_LINE_EVENTS_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    time_line_id: builtins.int
    """"""
    time_line_title: builtins.str
    """"""
    @property
    def time_line_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimeLineEvents]:
        """"""
    has_more: builtins.bool
    """"""
    def __init__(
        self,
        *,
        time_line_id: builtins.int = ...,
        time_line_title: builtins.str = ...,
        time_line_events: collections.abc.Iterable[global___TimeLineEvents] | None = ...,
        has_more: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "time_line_events", b"time_line_events", "time_line_id", b"time_line_id", "time_line_title", b"time_line_title"]) -> None: ...

global___TimeLineResource = TimeLineResource

@typing_extensions.final
class TopicActivities(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_FIELD_NUMBER: builtins.int
    ACT_LIST_TITLE_FIELD_NUMBER: builtins.int
    @property
    def activity(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicActivity]:
        """"""
    act_list_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity: collections.abc.Iterable[global___TopicActivity] | None = ...,
        act_list_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_list_title", b"act_list_title", "activity", b"activity"]) -> None: ...

global___TopicActivities = TopicActivities

@typing_extensions.final
class TopicActivity(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""
    activity_name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        activity_name: builtins.str = ...,
        jump_url: builtins.str = ...,
        icon_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "activity_name", b"activity_name", "icon_url", b"icon_url", "jump_url", b"jump_url"]) -> None: ...

global___TopicActivity = TopicActivity

@typing_extensions.final
class TopicCapsule(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        jump_url: builtins.str = ...,
        icon_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_url", b"icon_url", "jump_url", b"jump_url", "name", b"name"]) -> None: ...

global___TopicCapsule = TopicCapsule

@typing_extensions.final
class TopicCardItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DYNAMIC_ITEM_FIELD_NUMBER: builtins.int
    FORD_CARD_ITEM_FIELD_NUMBER: builtins.int
    VIDEO_SMALL_CARD_ITEM_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    @property
    def dynamic_item(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """"""
    @property
    def ford_card_item(self) -> global___FoldCardItem:
        """"""
    @property
    def video_small_card_item(self) -> global___VideoSmallCardItem:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        dynamic_item: bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem | None = ...,
        ford_card_item: global___FoldCardItem | None = ...,
        video_small_card_item: global___VideoSmallCardItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dynamic_item", b"dynamic_item", "ford_card_item", b"ford_card_item", "video_small_card_item", b"video_small_card_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_item", b"dynamic_item", "ford_card_item", b"ford_card_item", "type", b"type", "video_small_card_item", b"video_small_card_item"]) -> None: ...

global___TopicCardItem = TopicCardItem

@typing_extensions.final
class TopicCardList(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_CARD_ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    TOPIC_SORT_BY_CONF_FIELD_NUMBER: builtins.int
    @property
    def topic_card_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicCardItem]:
        """"""
    offset: builtins.str
    """"""
    has_more: builtins.bool
    """"""
    @property
    def topic_sort_by_conf(self) -> global___TopicSortByConf:
        """"""
    def __init__(
        self,
        *,
        topic_card_items: collections.abc.Iterable[global___TopicCardItem] | None = ...,
        offset: builtins.str = ...,
        has_more: builtins.bool = ...,
        topic_sort_by_conf: global___TopicSortByConf | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_sort_by_conf", b"topic_sort_by_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "offset", b"offset", "topic_card_items", b"topic_card_items", "topic_sort_by_conf", b"topic_sort_by_conf"]) -> None: ...

global___TopicCardList = TopicCardList

@typing_extensions.final
class TopicDetailsAllReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DETAILS_TOP_INFO_FIELD_NUMBER: builtins.int
    TOPIC_ACTIVITIES_FIELD_NUMBER: builtins.int
    TOPIC_CARD_LIST_FIELD_NUMBER: builtins.int
    FUNCTIONAL_CARD_FIELD_NUMBER: builtins.int
    PUB_LAYER_FIELD_NUMBER: builtins.int
    TIME_LINE_RESOURCE_FIELD_NUMBER: builtins.int
    TOPIC_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def details_top_info(self) -> global___DetailsTopInfo:
        """"""
    @property
    def topic_activities(self) -> global___TopicActivities:
        """"""
    @property
    def topic_card_list(self) -> global___TopicCardList:
        """"""
    @property
    def functional_card(self) -> global___FunctionalCard:
        """"""
    @property
    def pub_layer(self) -> global___PubLayer:
        """"""
    @property
    def time_line_resource(self) -> global___TimeLineResource:
        """"""
    @property
    def topic_server_config(self) -> global___TopicServerConfig:
        """"""
    def __init__(
        self,
        *,
        details_top_info: global___DetailsTopInfo | None = ...,
        topic_activities: global___TopicActivities | None = ...,
        topic_card_list: global___TopicCardList | None = ...,
        functional_card: global___FunctionalCard | None = ...,
        pub_layer: global___PubLayer | None = ...,
        time_line_resource: global___TimeLineResource | None = ...,
        topic_server_config: global___TopicServerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details_top_info", b"details_top_info", "functional_card", b"functional_card", "pub_layer", b"pub_layer", "time_line_resource", b"time_line_resource", "topic_activities", b"topic_activities", "topic_card_list", b"topic_card_list", "topic_server_config", b"topic_server_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["details_top_info", b"details_top_info", "functional_card", b"functional_card", "pub_layer", b"pub_layer", "time_line_resource", b"time_line_resource", "topic_activities", b"topic_activities", "topic_card_list", b"topic_card_list", "topic_server_config", b"topic_server_config"]) -> None: ...

global___TopicDetailsAllReply = TopicDetailsAllReply

@typing_extensions.final
class TopicDetailsAllReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    SORT_BY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    NEED_REFRESH_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TOPIC_DETAILS_EXT_MODE_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    sort_by: builtins.int
    """"""
    offset: builtins.str
    """"""
    page_size: builtins.int
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    need_refresh: builtins.int
    """"""
    source: builtins.str
    """"""
    topic_details_ext_mode: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        sort_by: builtins.int = ...,
        offset: builtins.str = ...,
        page_size: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        need_refresh: builtins.int = ...,
        source: builtins.str = ...,
        topic_details_ext_mode: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_time", b"local_time", "need_refresh", b"need_refresh", "offset", b"offset", "page_size", b"page_size", "player_args", b"player_args", "sort_by", b"sort_by", "source", b"source", "topic_details_ext_mode", b"topic_details_ext_mode", "topic_id", b"topic_id"]) -> None: ...

global___TopicDetailsAllReq = TopicDetailsAllReq

@typing_extensions.final
class TopicDetailsFoldReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_CARD_LIST_FIELD_NUMBER: builtins.int
    FOLD_COUNT_FIELD_NUMBER: builtins.int
    @property
    def topic_card_list(self) -> global___TopicCardList:
        """"""
    fold_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_card_list: global___TopicCardList | None = ...,
        fold_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_card_list", b"topic_card_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold_count", b"fold_count", "topic_card_list", b"topic_card_list"]) -> None: ...

global___TopicDetailsFoldReply = TopicDetailsFoldReply

@typing_extensions.final
class TopicDetailsFoldReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    LOCAL_TIME_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    FROM_SORT_BY_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    offset: builtins.str
    """"""
    page_size: builtins.int
    """"""
    local_time: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    from_sort_by: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        offset: builtins.str = ...,
        page_size: builtins.int = ...,
        local_time: builtins.int = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        from_sort_by: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_sort_by", b"from_sort_by", "local_time", b"local_time", "offset", b"offset", "page_size", b"page_size", "player_args", b"player_args", "topic_id", b"topic_id"]) -> None: ...

global___TopicDetailsFoldReq = TopicDetailsFoldReq

@typing_extensions.final
class TopicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DISCUSS_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    DYNAMICS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    BACKCOLOR_FIELD_NUMBER: builtins.int
    IS_FAV_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATE_SOURCE_FIELD_NUMBER: builtins.int
    SHARE_PIC_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    SHARE_URL_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATS_DESC_FIELD_NUMBER: builtins.int
    FIXED_TOPIC_ICON_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    uid: builtins.int
    """"""
    view: builtins.int
    """"""
    discuss: builtins.int
    """"""
    fav: builtins.int
    """"""
    dynamics: builtins.int
    """"""
    state: builtins.int
    """"""
    jump_url: builtins.str
    """"""
    backcolor: builtins.str
    """"""
    is_fav: builtins.bool
    """"""
    description: builtins.str
    """"""
    create_source: builtins.int
    """"""
    share_pic: builtins.str
    """"""
    share: builtins.int
    """"""
    like: builtins.int
    """"""
    share_url: builtins.str
    """"""
    is_like: builtins.bool
    """"""
    type: builtins.int
    """"""
    stats_desc: builtins.str
    """"""
    fixed_topic_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        uid: builtins.int = ...,
        view: builtins.int = ...,
        discuss: builtins.int = ...,
        fav: builtins.int = ...,
        dynamics: builtins.int = ...,
        state: builtins.int = ...,
        jump_url: builtins.str = ...,
        backcolor: builtins.str = ...,
        is_fav: builtins.bool = ...,
        description: builtins.str = ...,
        create_source: builtins.int = ...,
        share_pic: builtins.str = ...,
        share: builtins.int = ...,
        like: builtins.int = ...,
        share_url: builtins.str = ...,
        is_like: builtins.bool = ...,
        type: builtins.int = ...,
        stats_desc: builtins.str = ...,
        fixed_topic_icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backcolor", b"backcolor", "create_source", b"create_source", "description", b"description", "discuss", b"discuss", "dynamics", b"dynamics", "fav", b"fav", "fixed_topic_icon", b"fixed_topic_icon", "id", b"id", "is_fav", b"is_fav", "is_like", b"is_like", "jump_url", b"jump_url", "like", b"like", "name", b"name", "share", b"share", "share_pic", b"share_pic", "share_url", b"share_url", "state", b"state", "stats_desc", b"stats_desc", "type", b"type", "uid", b"uid", "view", b"view"]) -> None: ...

global___TopicInfo = TopicInfo

@typing_extensions.final
class TopicServerConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUB_EVENTS_INCREASE_THRESHOLD_FIELD_NUMBER: builtins.int
    PUB_EVENTS_HIDDEN_TIMEOUT_THRESHOLD_FIELD_NUMBER: builtins.int
    VERT_ONLINE_REFRESH_TIME_FIELD_NUMBER: builtins.int
    pub_events_increase_threshold: builtins.int
    """"""
    pub_events_hidden_timeout_threshold: builtins.int
    """"""
    vert_online_refresh_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        pub_events_increase_threshold: builtins.int = ...,
        pub_events_hidden_timeout_threshold: builtins.int = ...,
        vert_online_refresh_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pub_events_hidden_timeout_threshold", b"pub_events_hidden_timeout_threshold", "pub_events_increase_threshold", b"pub_events_increase_threshold", "vert_online_refresh_time", b"vert_online_refresh_time"]) -> None: ...

global___TopicServerConfig = TopicServerConfig

@typing_extensions.final
class TopicSet(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SET_ID_FIELD_NUMBER: builtins.int
    SET_NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    set_id: builtins.int
    """"""
    set_name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        set_id: builtins.int = ...,
        set_name: builtins.str = ...,
        jump_url: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "jump_url", b"jump_url", "set_id", b"set_id", "set_name", b"set_name"]) -> None: ...

global___TopicSet = TopicSet

@typing_extensions.final
class TopicSetDetailsReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_SET_HEAD_INFO_FIELD_NUMBER: builtins.int
    TOPIC_INFO_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    SORT_CFG_FIELD_NUMBER: builtins.int
    @property
    def topic_set_head_info(self) -> global___TopicSetHeadInfo:
        """"""
    @property
    def topic_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicInfo]:
        """"""
    has_more: builtins.bool
    """"""
    offset: builtins.str
    """"""
    @property
    def sort_cfg(self) -> global___TopicSetSortCfg:
        """"""
    def __init__(
        self,
        *,
        topic_set_head_info: global___TopicSetHeadInfo | None = ...,
        topic_info: collections.abc.Iterable[global___TopicInfo] | None = ...,
        has_more: builtins.bool = ...,
        offset: builtins.str = ...,
        sort_cfg: global___TopicSetSortCfg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sort_cfg", b"sort_cfg", "topic_set_head_info", b"topic_set_head_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more", b"has_more", "offset", b"offset", "sort_cfg", b"sort_cfg", "topic_info", b"topic_info", "topic_set_head_info", b"topic_set_head_info"]) -> None: ...

global___TopicSetDetailsReply = TopicSetDetailsReply

@typing_extensions.final
class TopicSetDetailsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SET_ID_FIELD_NUMBER: builtins.int
    SORT_BY_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    set_id: builtins.int
    """"""
    sort_by: builtins.int
    """"""
    offset: builtins.str
    """"""
    page_size: builtins.int
    """"""
    def __init__(
        self,
        *,
        set_id: builtins.int = ...,
        sort_by: builtins.int = ...,
        offset: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset", b"offset", "page_size", b"page_size", "set_id", b"set_id", "sort_by", b"sort_by"]) -> None: ...

global___TopicSetDetailsReq = TopicSetDetailsReq

@typing_extensions.final
class TopicSetHeadInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_SET_FIELD_NUMBER: builtins.int
    TOPIC_CNT_TEXT_FIELD_NUMBER: builtins.int
    HEAD_IMG_URL_FIELD_NUMBER: builtins.int
    MISSION_URL_FIELD_NUMBER: builtins.int
    MISSION_TEXT_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    IS_FAV_FIELD_NUMBER: builtins.int
    IS_FIRST_TIME_FIELD_NUMBER: builtins.int
    @property
    def topic_set(self) -> global___TopicSet:
        """"""
    topic_cnt_text: builtins.str
    """"""
    head_img_url: builtins.str
    """"""
    mission_url: builtins.str
    """"""
    mission_text: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    is_fav: builtins.bool
    """"""
    is_first_time: builtins.bool
    """"""
    def __init__(
        self,
        *,
        topic_set: global___TopicSet | None = ...,
        topic_cnt_text: builtins.str = ...,
        head_img_url: builtins.str = ...,
        mission_url: builtins.str = ...,
        mission_text: builtins.str = ...,
        icon_url: builtins.str = ...,
        is_fav: builtins.bool = ...,
        is_first_time: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic_set", b"topic_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["head_img_url", b"head_img_url", "icon_url", b"icon_url", "is_fav", b"is_fav", "is_first_time", b"is_first_time", "mission_text", b"mission_text", "mission_url", b"mission_url", "topic_cnt_text", b"topic_cnt_text", "topic_set", b"topic_set"]) -> None: ...

global___TopicSetHeadInfo = TopicSetHeadInfo

@typing_extensions.final
class TopicSetSortCfg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_SORT_BY_FIELD_NUMBER: builtins.int
    ALL_SORT_BY_FIELD_NUMBER: builtins.int
    default_sort_by: builtins.int
    """"""
    @property
    def all_sort_by(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortContent]:
        """"""
    def __init__(
        self,
        *,
        default_sort_by: builtins.int = ...,
        all_sort_by: collections.abc.Iterable[global___SortContent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_sort_by", b"all_sort_by", "default_sort_by", b"default_sort_by"]) -> None: ...

global___TopicSetSortCfg = TopicSetSortCfg

@typing_extensions.final
class TopicSortByConf(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_SORT_BY_FIELD_NUMBER: builtins.int
    ALL_SORT_BY_FIELD_NUMBER: builtins.int
    SHOW_SORT_BY_FIELD_NUMBER: builtins.int
    default_sort_by: builtins.int
    """"""
    @property
    def all_sort_by(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SortContent]:
        """"""
    show_sort_by: builtins.int
    """"""
    def __init__(
        self,
        *,
        default_sort_by: builtins.int = ...,
        all_sort_by: collections.abc.Iterable[global___SortContent] | None = ...,
        show_sort_by: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_sort_by", b"all_sort_by", "default_sort_by", b"default_sort_by", "show_sort_by", b"show_sort_by"]) -> None: ...

global___TopicSortByConf = TopicSortByConf

@typing_extensions.final
class TopicThreePoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_THREE_POINT_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def dyn_three_point_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreePointItem]:
        """"""
    def __init__(
        self,
        *,
        dyn_three_point_items: collections.abc.Iterable[global___ThreePointItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_three_point_items", b"dyn_three_point_items"]) -> None: ...

global___TopicThreePoint = TopicThreePoint

@typing_extensions.final
class TrafficCard(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ICON_URL_FIELD_NUMBER: builtins.int
    BASE_PIC_FIELD_NUMBER: builtins.int
    BENEFIT_POINT_FIELD_NUMBER: builtins.int
    CARD_DESC_FIELD_NUMBER: builtins.int
    JUMP_TITLE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    icon_url: builtins.str
    """"""
    base_pic: builtins.str
    """"""
    benefit_point: builtins.str
    """"""
    card_desc: builtins.str
    """"""
    jump_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        jump_url: builtins.str = ...,
        icon_url: builtins.str = ...,
        base_pic: builtins.str = ...,
        benefit_point: builtins.str = ...,
        card_desc: builtins.str = ...,
        jump_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_pic", b"base_pic", "benefit_point", b"benefit_point", "card_desc", b"card_desc", "icon_url", b"icon_url", "jump_title", b"jump_title", "jump_url", b"jump_url", "name", b"name"]) -> None: ...

global___TrafficCard = TrafficCard

@typing_extensions.final
class User(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_DESC_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    face: builtins.str
    """"""
    name: builtins.str
    """"""
    name_desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        name_desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "name", b"name", "name_desc", b"name_desc", "uid", b"uid"]) -> None: ...

global___User = User

@typing_extensions.final
class VideoCardBase(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    UP_NAME_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    title: builtins.str
    """"""
    up_name: builtins.str
    """"""
    play: builtins.int
    """"""
    jump_link: builtins.str
    """"""
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        title: builtins.str = ...,
        up_name: builtins.str = ...,
        play: builtins.int = ...,
        jump_link: builtins.str = ...,
        aid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cover", b"cover", "jump_link", b"jump_link", "play", b"play", "title", b"title", "up_name", b"up_name"]) -> None: ...

global___VideoCardBase = VideoCardBase

@typing_extensions.final
class VideoSmallCardItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_CARD_BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_BADGE_TEXT_FIELD_NUMBER: builtins.int
    CARD_STAT_ICON1_FIELD_NUMBER: builtins.int
    CARD_STAT_TEXT1_FIELD_NUMBER: builtins.int
    CARD_STAT_ICON2_FIELD_NUMBER: builtins.int
    CARD_STAT_TEXT2_FIELD_NUMBER: builtins.int
    @property
    def video_card_base(self) -> global___VideoCardBase:
        """"""
    cover_left_badge_text: builtins.str
    """"""
    card_stat_icon1: builtins.int
    """"""
    card_stat_text1: builtins.str
    """"""
    card_stat_icon2: builtins.int
    """"""
    card_stat_text2: builtins.str
    """"""
    def __init__(
        self,
        *,
        video_card_base: global___VideoCardBase | None = ...,
        cover_left_badge_text: builtins.str = ...,
        card_stat_icon1: builtins.int = ...,
        card_stat_text1: builtins.str = ...,
        card_stat_icon2: builtins.int = ...,
        card_stat_text2: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["video_card_base", b"video_card_base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_stat_icon1", b"card_stat_icon1", "card_stat_icon2", b"card_stat_icon2", "card_stat_text1", b"card_stat_text1", "card_stat_text2", b"card_stat_text2", "cover_left_badge_text", b"cover_left_badge_text", "video_card_base", b"video_card_base"]) -> None: ...

global___VideoSmallCardItem = VideoSmallCardItem



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.broadcast.message.main import search_pb2 as bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class SearchStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ChatResultPush = channel.unary_stream(
                '/bilibili.broadcast.message.main.Search/ChatResultPush',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2.ChatResult.FromString,
                )


class SearchServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ChatResultPush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ChatResultPush': grpc.unary_stream_rpc_method_handler(
                    servicer.ChatResultPush,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2.ChatResult.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.message.main.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ChatResultPush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bilibili.broadcast.message.main.Search/ChatResultPush',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2.ChatResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/message/main/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/broadcast/message/main/search.proto\x12\x1f\x62ilibili.broadcast.message.main\x1a\x1bgoogle/protobuf/empty.proto\x1a%bilibili/app/dynamic/v2/dynamic.proto\"@\n\x06\x42ubble\x12\x36\n\nparagraphs\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v2.Paragraph\"\x8c\x01\n\nChatResult\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x37\n\x06\x62ubble\x18\x03 \x03(\x0b\x32\'.bilibili.broadcast.message.main.Bubble\x12\x14\n\x0crewrite_word\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t2a\n\x06Search\x12W\n\x0e\x43hatResultPush\x12\x16.google.protobuf.Empty\x1a+.bilibili.broadcast.message.main.ChatResult0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.main.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BUBBLE']._serialized_start=149
  _globals['_BUBBLE']._serialized_end=213
  _globals['_CHATRESULT']._serialized_start=216
  _globals['_CHATRESULT']._serialized_end=356
  _globals['_SEARCH']._serialized_start=358
  _globals['_SEARCH']._serialized_end=455
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/playerunite/v1/playerunite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.playershared import playershared_pb2 as bilibili_dot_playershared_dot_playershared__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-bilibili/app/playerunite/v1/playerunite.proto\x12\x1b\x62ilibili.app.playerunite.v1\x1a(bilibili/playershared/playershared.proto\x1a\x19google/protobuf/any.proto\"\xf0\x01\n\x10PlayViewUniteReq\x12,\n\x03vod\x18\x01 \x01(\x0b\x32\x1f.bilibili.playershared.VideoVod\x12\r\n\x05spmid\x18\x02 \x01(\t\x12\x12\n\nfrom_spmid\x18\x03 \x01(\t\x12V\n\rextra_content\x18\x04 \x03(\x0b\x32?.bilibili.app.playerunite.v1.PlayViewUniteReq.ExtraContentEntry\x1a\x33\n\x11\x45xtraContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x03\n\x12PlayViewUniteReply\x12\x30\n\x08vod_info\x18\x01 \x01(\x0b\x32\x1e.bilibili.playershared.VodInfo\x12\x39\n\rplay_arc_conf\x18\x02 \x01(\x0b\x32\".bilibili.playershared.PlayArcConf\x12?\n\x10play_device_conf\x18\x03 \x01(\x0b\x32%.bilibili.playershared.PlayDeviceConf\x12+\n\x05\x65vent\x18\x04 \x01(\x0b\x32\x1c.bilibili.playershared.Event\x12(\n\nsupplement\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x30\n\x08play_arc\x18\x06 \x01(\x0b\x32\x1e.bilibili.playershared.PlayArc\x12\x39\n\rqn_trial_info\x18\x07 \x01(\x0b\x32\".bilibili.playershared.QnTrialInfo\x12/\n\x07history\x18\x08 \x01(\x0b\x32\x1e.bilibili.playershared.History2y\n\x06Player\x12o\n\rPlayViewUnite\x12-.bilibili.app.playerunite.v1.PlayViewUniteReq\x1a/.bilibili.app.playerunite.v1.PlayViewUniteReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.playerunite.v1.playerunite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYVIEWUNITEREQ_EXTRACONTENTENTRY._options = None
  _PLAYVIEWUNITEREQ_EXTRACONTENTENTRY._serialized_options = b'8\001'
  _globals['_PLAYVIEWUNITEREQ']._serialized_start=148
  _globals['_PLAYVIEWUNITEREQ']._serialized_end=388
  _globals['_PLAYVIEWUNITEREQ_EXTRACONTENTENTRY']._serialized_start=337
  _globals['_PLAYVIEWUNITEREQ_EXTRACONTENTENTRY']._serialized_end=388
  _globals['_PLAYVIEWUNITEREPLY']._serialized_start=391
  _globals['_PLAYVIEWUNITEREPLY']._serialized_end=830
  _globals['_PLAYER']._serialized_start=832
  _globals['_PLAYER']._serialized_end=953
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/web/interfaces/v1/interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+bilibili/web/interfaces/v1/interfaces.proto\x12\x1a\x62ilibili.web.interfaces.v1\"M\n\x07\x41\x63\x63Info\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\"\x8c\x04\n\x0b\x41\x63\x63ountCard\x12\x0b\n\x03mid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04rank\x18\x04 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x05 \x01(\t\x12\x10\n\x08spacesta\x18\x06 \x01(\x05\x12\x0c\n\x04sign\x18\x07 \x01(\t\x12=\n\nlevel_info\x18\x08 \x01(\x0b\x32).bilibili.web.interfaces.v1.CardLevelInfo\x12\x38\n\x07pendant\x18\t \x01(\x0b\x32\'.bilibili.web.interfaces.v1.PendantInfo\x12<\n\tnameplate\x18\n \x01(\x0b\x32).bilibili.web.interfaces.v1.NameplateInfo\x12:\n\x08official\x18\x0b \x01(\x0b\x32(.bilibili.web.interfaces.v1.OfficialInfo\x12\x43\n\x0fofficial_verify\x18\x0c \x01(\x0b\x32*.bilibili.web.interfaces.v1.OfficialVerify\x12\x30\n\x03vip\x18\r \x01(\x0b\x32#.bilibili.web.interfaces.v1.CardVip\x12\x0c\n\x04\x66\x61ns\x18\x0e \x01(\x03\x12\x0e\n\x06\x66riend\x18\x0f \x01(\x03\x12\x11\n\tattention\x18\x10 \x01(\x03\"\xf3\x02\n\x14\x41\x63tivityArchiveReply\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12/\n\x05pages\x18\x03 \x03(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x35\n\x08req_user\x18\x04 \x01(\x0b\x32#.bilibili.web.interfaces.v1.ReqUser\x12\x30\n\x05staff\x18\x05 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Staff\x12\x41\n\x0cright_relate\x18\x06 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x42\n\rbottom_relate\x18\x07 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\"E\n\x12\x41\x63tivityArchiveReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63tivity_key\x18\x03 \x01(\t\"\xcb\x01\n\x0f\x41\x63tivityEpisode\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x03 \x01(\t\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\r\n\x05title\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x32\n\x06\x61uthor\x18\x07 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Author\x12\x32\n\x06rights\x18\x08 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Rights\"{\n\x0c\x41\x63tivityGame\x12?\n\x07iframes\x18\x01 \x03(\x0b\x32..bilibili.web.interfaces.v1.ActivityGameIframe\x12\x12\n\ndisclaimer\x18\x02 \x01(\t\x12\x16\n\x0e\x64isclaimer_url\x18\x03 \x01(\t\"1\n\x12\x41\x63tivityGameIframe\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x03\"\xf2\x02\n\x0c\x41\x63tivityLive\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x10\n\x08now_time\x18\x02 \x01(\x03\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x03\x12\x11\n\thover_pic\x18\x05 \x01(\t\x12\x16\n\x0ehover_jump_url\x18\x06 \x01(\t\x12\x13\n\x0b\x62reak_cycle\x18\x07 \x01(\x03\x12:\n\x08timeline\x18\x08 \x03(\x0b\x32(.bilibili.web.interfaces.v1.LiveTimeline\x12\x45\n\x10operation_relate\x18\t \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x12\n\nreply_type\x18\n \x01(\x03\x12\x10\n\x08reply_id\x18\x0b \x01(\x03\x12\x17\n\x0fhover_pic_close\x18\x0c \x01(\t\x12\x17\n\x0fgift_disclaimer\x18\r \x01(\t\"\x8f\x01\n\x19\x41\x63tivityLiveTimeInfoReply\x12\x10\n\x08now_time\x18\x01 \x01(\x03\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\x12:\n\x08timeline\x18\x04 \x03(\x0b\x32(.bilibili.web.interfaces.v1.LiveTimeline\"/\n\x17\x41\x63tivityLiveTimeInfoReq\x12\x14\n\x0c\x61\x63tivity_key\x18\x01 \x01(\t\"\x8a\x03\n\x13\x41\x63tivitySeasonReply\x12@\n\x06status\x18\x01 \x01(\x0e\x32\x30.bilibili.web.interfaces.v1.ActivitySeasonStatus\x12\r\n\x05title\x18\x02 \x01(\t\x12\x36\n\x04live\x18\x03 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ActivityLive\x12@\n\tsubscribe\x18\x04 \x01(\x0b\x32-.bilibili.web.interfaces.v1.ActivitySubscribe\x12\x36\n\x04game\x18\x05 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ActivityGame\x12\x36\n\x04view\x18\x06 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ActivityView\x12\x38\n\x05theme\x18\x07 \x01(\x0b\x32).bilibili.web.interfaces.v1.ActivityTheme\"D\n\x11\x41\x63tivitySeasonReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63tivity_key\x18\x03 \x01(\t\"\x7f\n\x15\x41\x63tivitySeasonSection\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12=\n\x08\x65pisodes\x18\x04 \x03(\x0b\x32+.bilibili.web.interfaces.v1.ActivityEpisode\"\xc2\x03\n\x11\x41\x63tivitySubscribe\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\r\n\x05title\x18\x02 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x03 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x04 \x01(\t\x12\x18\n\x10season_stat_view\x18\x05 \x01(\x03\x12\x1b\n\x13season_stat_danmaku\x18\x06 \x01(\x03\x12\x39\n\norder_type\x18\x07 \x01(\x0e\x32%.bilibili.web.interfaces.v1.OrderType\x12R\n\x16reserve_activity_param\x18\x08 \x01(\x0b\x32\x30.bilibili.web.interfaces.v1.ReserveActivityParamH\x00\x12\x46\n\x10\x66\x61v_season_param\x18\t \x01(\x0b\x32*.bilibili.web.interfaces.v1.FavSeasonParamH\x00\x12\x42\n\x0ejump_URL_param\x18\n \x01(\x0b\x32(.bilibili.web.interfaces.v1.JumpURLParamH\x00\x42\x07\n\x05param\"\x9f\x06\n\rActivityTheme\x12\x12\n\nbase_color\x18\x01 \x01(\t\x12\x18\n\x10loading_bg_color\x18\x02 \x01(\t\x12\x19\n\x11operated_bg_color\x18\x03 \x01(\t\x12\x1d\n\x15\x64\x65\x66\x61ult_element_color\x18\x04 \x01(\t\x12\x1b\n\x13hover_element_color\x18\x05 \x01(\t\x12\x1e\n\x16selected_element_color\x18\x06 \x01(\t\x12\x17\n\x0f\x62\x61se_font_color\x18\x07 \x01(\t\x12\x17\n\x0finfo_font_color\x18\x08 \x01(\t\x12\x15\n\rmask_bg_color\x18\t \x01(\t\x12\x15\n\rpage_bg_color\x18\n \x01(\t\x12\x17\n\x0f\x63\x65nter_logo_img\x18\x0b \x01(\t\x12\x13\n\x0bpage_bg_img\x18\x0c \x01(\t\x12\x1b\n\x13\x64\x65\x63orations2233_img\x18\r \x01(\t\x12\x1a\n\x12main_banner_bg_img\x18\x0e \x01(\t\x12\x1d\n\x15main_banner_title_img\x18\x0f \x01(\t\x12\x1a\n\x12like_animation_img\x18\x10 \x01(\t\x12\x16\n\x0e\x63ombo_like_img\x18\x11 \x01(\t\x12\x16\n\x0e\x63ombo_coin_img\x18\x12 \x01(\t\x12\x15\n\rcombo_fav_img\x18\x13 \x01(\t\x12\x15\n\rarrow_btn_img\x18\x14 \x01(\t\x12\x19\n\x11share_icon_bg_img\x18\x15 \x01(\t\x12\x1e\n\x16live_list_location_img\x18\x16 \x01(\t\x12%\n\x1dlive_list_location_img_active\x18\x17 \x01(\t\x12\x1a\n\x12player_loading_img\x18\x18 \x01(\t\x12\x11\n\tshare_img\x18\x19 \x01(\t\x12H\n\x08kv_color\x18\x1a \x03(\x0b\x32\x36.bilibili.web.interfaces.v1.ActivityTheme.KvColorEntry\x1a.\n\x0cKvColorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x03\n\x0c\x41\x63tivityView\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12/\n\x05pages\x18\x03 \x03(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x30\n\x05staff\x18\x04 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Staff\x12\x35\n\x08req_user\x18\x05 \x01(\x0b\x32#.bilibili.web.interfaces.v1.ReqUser\x12\x41\n\x0cright_relate\x18\x06 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x42\n\rbottom_relate\x18\x07 \x01(\x0b\x32+.bilibili.web.interfaces.v1.OperationRelate\x12\x43\n\x08sections\x18\x08 \x03(\x0b\x32\x31.bilibili.web.interfaces.v1.ActivitySeasonSection\"\x91\x06\n\x03\x41rc\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0e\n\x06videos\x18\x02 \x01(\x03\x12\x0f\n\x07type_id\x18\x03 \x01(\x05\x12\x11\n\ttype_name\x18\x04 \x01(\t\x12\x11\n\tcopyright\x18\x05 \x01(\x05\x12\x0b\n\x03pic\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07pubdate\x18\x08 \x01(\x03\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\x05\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x05\x12\x11\n\tattribute\x18\r \x01(\x05\x12\x0b\n\x03tag\x18\x0e \x01(\t\x12\x0c\n\x04tags\x18\x0f \x03(\t\x12\x10\n\x08\x64uration\x18\x10 \x01(\x03\x12\x12\n\nmission_id\x18\x11 \x01(\x03\x12\x10\n\x08order_id\x18\x12 \x01(\x03\x12\x14\n\x0credirect_url\x18\x13 \x01(\t\x12\x0f\n\x07\x66orward\x18\x14 \x01(\x03\x12\x32\n\x06rights\x18\x15 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Rights\x12\x32\n\x06\x61uthor\x18\x16 \x01(\x0b\x32\".bilibili.web.interfaces.v1.Author\x12.\n\x04stat\x18\x17 \x01(\x0b\x32 .bilibili.web.interfaces.v1.Stat\x12\x15\n\rreport_result\x18\x18 \x01(\t\x12\x0f\n\x07\x64ynamic\x18\x19 \x01(\t\x12\x11\n\tfirst_cid\x18\x1a \x01(\x03\x12\x38\n\tdimension\x18\x1b \x01(\x0b\x32%.bilibili.web.interfaces.v1.Dimension\x12\x39\n\nstaff_info\x18\x1c \x03(\x0b\x32%.bilibili.web.interfaces.v1.StaffInfo\x12\x11\n\tseason_id\x18\x1d \x01(\x03\x12\x33\n\x07\x64\x65sc_v2\x18\x1e \x03(\x0b\x32\".bilibili.web.interfaces.v1.DescV2\x12\x1c\n\x14is_chargeable_season\x18\x1f \x01(\x08\x12\x12\n\nis_blooper\x18  \x01(\x08\"1\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\"\xc2\x01\n\x04\x43\x61rd\x12\x35\n\x04\x63\x61rd\x18\x01 \x01(\x0b\x32\'.bilibili.web.interfaces.v1.AccountCard\x12\x30\n\x05space\x18\x02 \x01(\x0b\x32!.bilibili.web.interfaces.v1.Space\x12\x11\n\tfollowing\x18\x03 \x01(\x08\x12\x15\n\rarchive_count\x18\x04 \x01(\x03\x12\x15\n\rarticle_count\x18\x05 \x01(\x05\x12\x10\n\x08\x66ollower\x18\x06 \x01(\x03\"L\n\rCardLevelInfo\x12\x0b\n\x03\x63ur\x18\x01 \x01(\x05\x12\x0b\n\x03min\x18\x02 \x01(\x05\x12\x0f\n\x07now_exp\x18\x03 \x01(\x05\x12\x10\n\x08next_exp\x18\x04 \x01(\x05\"\x83\x01\n\x07\x43\x61rdVip\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x12\n\ndue_remark\x18\x02 \x01(\t\x12\x15\n\raccess_status\x18\x03 \x01(\x05\x12\x12\n\nvip_status\x18\x04 \x01(\x05\x12\x17\n\x0fvip_status_warn\x18\x05 \x01(\t\x12\x12\n\ntheme_type\x18\x06 \x01(\x05\"\xdb\x02\n\x16\x43lickActivitySeasonReq\x12\x39\n\norder_type\x18\x01 \x01(\x0e\x32%.bilibili.web.interfaces.v1.OrderType\x12R\n\x16reserve_activity_param\x18\x02 \x01(\x0b\x32\x30.bilibili.web.interfaces.v1.ReserveActivityParamH\x00\x12\x46\n\x10\x66\x61v_season_param\x18\x03 \x01(\x0b\x32*.bilibili.web.interfaces.v1.FavSeasonParamH\x00\x12\x42\n\x0ejump_URL_param\x18\x04 \x01(\x0b\x32(.bilibili.web.interfaces.v1.JumpURLParamH\x00\x12\r\n\x05spmid\x18\x05 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x06 \x01(\x03\x42\x07\n\x05param\"8\n\x06\x44\x65scV2\x12\x10\n\x08raw_text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\x0e\n\x06\x62iz_id\x18\x03 \x01(\x03\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"#\n\x0e\x46\x61vSeasonParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"s\n\x08HotReply\x12\x33\n\x04page\x18\x01 \x01(\x0b\x32%.bilibili.web.interfaces.v1.ReplyPage\x12\x32\n\x07replies\x18\x02 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Reply\" \n\x0cJumpURLParam\x12\x10\n\x08jump_url\x18\x01 \x01(\t\"u\n\x0cLiveTimeline\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08subtitle\x18\x05 \x01(\t\x12\x10\n\x08h5_cover\x18\x06 \x01(\t\"p\n\rNameplateInfo\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"\t\n\x07NoReply\"9\n\x0cOfficialInfo\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"\x99\x01\n\x0fOperationRelate\x12\r\n\x05title\x18\x01 \x01(\t\x12;\n\x0brelate_item\x18\x02 \x03(\x0b\x32&.bilibili.web.interfaces.v1.RelateItem\x12:\n\x0e\x61i_relate_item\x18\x03 \x03(\x0b\x32\".bilibili.web.interfaces.v1.Relate\"\xb5\x01\n\x04Page\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0c\n\x04part\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03vid\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x07 \x01(\t\x12\x0f\n\x07weblink\x18\x08 \x01(\t\x12\x38\n\tdimension\x18\t \x01(\x0b\x32%.bilibili.web.interfaces.v1.Dimension\"G\n\x0bPendantInfo\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\x1b\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\"Y\n\x06Relate\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x13\n\x0bseason_type\x18\x03 \x01(\x03\"(\n\nRelateItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\".\n\x08Relation\x12\x11\n\tattribute\x18\x01 \x01(\x03\x12\x0f\n\x07special\x18\x03 \x01(\x03\"\xdf\x05\n\x05Reply\x12\x0c\n\x04rpid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\x0c\n\x04root\x18\x05 \x01(\x03\x12\x0e\n\x06parent\x18\x06 \x01(\x03\x12\x0e\n\x06\x64ialog\x18\x07 \x01(\x03\x12\r\n\x05\x63ount\x18\x08 \x01(\x05\x12\x0e\n\x06rcount\x18\t \x01(\x05\x12\r\n\x05\x66loor\x18\n \x01(\x05\x12\r\n\x05state\x18\x0b \x01(\x05\x12\x12\n\nfans_grade\x18\x0c \x01(\x05\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\x12\r\n\x05\x63time\x18\x0e \x01(\x03\x12\x10\n\x08rpid_str\x18\x0f \x01(\t\x12\x10\n\x08root_str\x18\x10 \x01(\t\x12\x12\n\nparent_str\x18\x11 \x01(\t\x12\x12\n\ndialog_str\x18\x12 \x01(\t\x12\x0c\n\x04like\x18\x13 \x01(\x05\x12\x0c\n\x04hate\x18\x14 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x15 \x01(\x05\x12\x37\n\x06member\x18\x16 \x01(\x0b\x32\'.bilibili.web.interfaces.v1.ReplyMember\x12\x39\n\x07\x63ontent\x18\x17 \x01(\x0b\x32(.bilibili.web.interfaces.v1.ReplyContent\x12\x32\n\x07replies\x18\x18 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Reply\x12\x0e\n\x06\x61ssist\x18\x19 \x01(\x05\x12\x37\n\x06\x66older\x18\x1a \x01(\x0b\x32\'.bilibili.web.interfaces.v1.ReplyFolder\x12<\n\tup_action\x18\x1b \x01(\x0b\x32).bilibili.web.interfaces.v1.ReplyUpAction\x12\x35\n\x05label\x18\x1c \x01(\x0b\x32&.bilibili.web.interfaces.v1.ReplyLabel\x12\x11\n\traw_input\x18\x1d \x01(\t\x12\x13\n\x0bshow_follow\x18\x1e \x01(\x08\"\x86\x03\n\x0cReplyContent\x12\r\n\x05rp_id\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x33\n\x04vote\x18\x03 \x01(\x0b\x32%.bilibili.web.interfaces.v1.ReplyVote\x12\x0e\n\x06topics\x18\x05 \x03(\t\x12\n\n\x02ip\x18\x06 \x01(\x05\x12\x0c\n\x04plat\x18\x07 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12<\n\x07members\x18\n \x03(\x0b\x32+.bilibili.web.interfaces.v1.ReplyMemberInfo\x12\x42\n\x05\x65mote\x18\x0b \x03(\x0b\x32\x33.bilibili.web.interfaces.v1.ReplyContent.EmoteEntry\x1aT\n\nEmoteEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.bilibili.web.interfaces.v1.ReplyEmote:\x02\x38\x01\"\xca\x01\n\nReplyEmote\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x12\n\npackage_id\x18\x02 \x01(\x03\x12\r\n\x05state\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12\x0c\n\x04\x61ttr\x18\x05 \x01(\x03\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\x12\x38\n\x04meta\x18\x08 \x01(\x0b\x32*.bilibili.web.interfaces.v1.ReplyEmoteMeta\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\r\n\x05mtime\x18\n \x01(\x03\"N\n\x0eReplyEmoteMeta\x12<\n\x04size\x18\x01 \x01(\x0e\x32..bilibili.web.interfaces.v1.ReplyEmoteMetaSize\"\x96\x01\n\x0fReplyFansDetail\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x10\n\x08medal_id\x18\x02 \x01(\x05\x12\x12\n\nmedal_name\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x05\x12\r\n\x05level\x18\x05 \x01(\x05\x12\x10\n\x08intimacy\x18\x06 \x01(\x05\x12\x0e\n\x06status\x18\x07 \x01(\x05\x12\x10\n\x08received\x18\x08 \x01(\x05\"B\n\x0bReplyFolder\x12\x12\n\nhas_folded\x18\x01 \x01(\x08\x12\x11\n\tis_folded\x18\x02 \x01(\x08\x12\x0c\n\x04rule\x18\x03 \x01(\t\"\xad\x01\n\nReplyLabel\x12\x0c\n\x04rpid\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\x12\x1d\n\x15text_color_night_mode\x18\x04 \x01(\t\x12\x10\n\x08\x62g_color\x18\x05 \x01(\t\x12\x1b\n\x13\x62g_color_night_mode\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\x10\n\x08position\x18\x08 \x01(\t\"M\n\x0eReplyLevelInfo\x12\x0b\n\x03\x63ur\x18\x01 \x01(\x05\x12\x0b\n\x03min\x18\x02 \x01(\x05\x12\x0f\n\x07now_exp\x18\x03 \x01(\x05\x12\x10\n\x08next_exp\x18\x04 \x01(\x05\"\x9d\x01\n\x0bReplyMember\x12\x39\n\x04info\x18\x01 \x01(\x0b\x32+.bilibili.web.interfaces.v1.ReplyMemberInfo\x12@\n\x0b\x66\x61ns_detail\x18\x02 \x01(\x0b\x32+.bilibili.web.interfaces.v1.ReplyFansDetail\x12\x11\n\tfollowing\x18\x03 \x01(\x05\"\xb9\x03\n\x0fReplyMemberInfo\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\x0b\n\x03mid\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03sex\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x06 \x01(\t\x12\x0c\n\x04rank\x18\x07 \x01(\t\x12\x14\n\x0c\x64isplay_rank\x18\x08 \x01(\t\x12>\n\nlevel_info\x18\t \x01(\x0b\x32*.bilibili.web.interfaces.v1.ReplyLevelInfo\x12\x38\n\x07pendant\x18\n \x01(\x0b\x32\'.bilibili.web.interfaces.v1.PendantInfo\x12<\n\tnameplate\x18\x0b \x01(\x0b\x32).bilibili.web.interfaces.v1.NameplateInfo\x12\x43\n\x0fofficial_verify\x18\x0c \x01(\x0b\x32*.bilibili.web.interfaces.v1.OfficialVerify\x12\x31\n\x03vip\x18\r \x01(\x0b\x32$.bilibili.web.interfaces.v1.ReplyVip\"E\n\tReplyPage\x12\x0e\n\x06\x61\x63ount\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x0b\n\x03num\x18\x03 \x01(\x03\x12\x0c\n\x04size\x18\x04 \x01(\x03\",\n\rReplyUpAction\x12\x0c\n\x04like\x18\x01 \x01(\x08\x12\r\n\x05reply\x18\x02 \x01(\x08\"\xcb\x01\n\x08ReplyVip\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x02 \x01(\x03\x12\x12\n\ndue_remark\x18\x03 \x01(\t\x12\x15\n\raccess_status\x18\x04 \x01(\x05\x12\x12\n\nvip_status\x18\x05 \x01(\x05\x12\x17\n\x0fvip_status_warn\x18\x06 \x01(\t\x12\x12\n\ntheme_type\x18\x07 \x01(\x05\x12\x33\n\x05label\x18\x08 \x01(\x0b\x32$.bilibili.web.interfaces.v1.VipLabel\"R\n\tReplyVote\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63nt\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08\"L\n\x07ReqUser\x12\x10\n\x08\x66\x61vorite\x18\x01 \x01(\x08\x12\x0c\n\x04like\x18\x02 \x01(\x08\x12\x0f\n\x07\x64islike\x18\x03 \x01(\x08\x12\x10\n\x08multiply\x18\x04 \x01(\x03\"S\n\x14ReserveActivityParam\x12\x12\n\nreserve_id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\x03\"\xea\x01\n\x06Rights\x12\n\n\x02\x62p\x18\x01 \x01(\x05\x12\x0c\n\x04\x65lec\x18\x02 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x03 \x01(\x05\x12\r\n\x05movie\x18\x04 \x01(\x05\x12\x0b\n\x03pay\x18\x05 \x01(\x05\x12\x0b\n\x03hd5\x18\x06 \x01(\x05\x12\x12\n\nno_reprint\x18\x07 \x01(\x05\x12\x10\n\x08\x61utoplay\x18\x08 \x01(\x05\x12\x0f\n\x07ugc_pay\x18\t \x01(\x05\x12\x16\n\x0eis_cooperation\x18\n \x01(\x05\x12\x17\n\x0fugc_pay_preview\x18\x0b \x01(\x05\x12\x0f\n\x07\x61rc_pay\x18\x0c \x01(\x05\x12\x12\n\nfree_watch\x18\r \x01(\x05\"\xa8\x02\n\rSeasonEpisode\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x12\n\nsection_id\x18\x02 \x01(\x03\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\x11\n\tattribute\x18\x07 \x01(\x03\x12,\n\x03\x61rc\x18\x08 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12.\n\x04page\x18\t \x01(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x0c\n\x04\x62vid\x18\n \x01(\t\x12<\n\x0b\x62\x61\x64ge_style\x18\x0b \x01(\x0b\x32\'.bilibili.web.interfaces.v1.ReasonStyle\"\x88\x01\n\rSeasonSection\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\n\n\x02id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12;\n\x08\x65pisodes\x18\x05 \x03(\x0b\x32).bilibili.web.interfaces.v1.SeasonEpisode\"\xa9\x01\n\nSeasonStat\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\"%\n\x05Space\x12\r\n\x05s_img\x18\x01 \x01(\t\x12\r\n\x05l_img\x18\x02 \x01(\t\"\x8c\x02\n\x05Staff\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x30\n\x03vip\x18\x05 \x01(\x0b\x32#.bilibili.web.interfaces.v1.VipInfo\x12:\n\x08official\x18\x06 \x01(\x0b\x32(.bilibili.web.interfaces.v1.OfficialInfo\x12\x10\n\x08\x66ollower\x18\x07 \x01(\x03\x12\x13\n\x0blabel_style\x18\x08 \x01(\x05\x12\x36\n\x08relation\x18\t \x01(\x0b\x32$.bilibili.web.interfaces.v1.Relation\"\'\n\tStaffInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\"\xd5\x01\n\x04Stat\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\x12\x0f\n\x07\x64islike\x18\x0b \x01(\x05\x12\x12\n\nevaluation\x18\x0c \x01(\t\x12\x11\n\targue_msg\x18\r \x01(\t\"X\n\x08Subtitle\x12\x14\n\x0c\x61llow_submit\x18\x01 \x01(\x08\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.bilibili.web.interfaces.v1.SubtitleItem\"\xa8\x01\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03lan\x18\x02 \x01(\t\x12\x0f\n\x07lan_doc\x18\x03 \x01(\t\x12\x0f\n\x07is_lock\x18\x04 \x01(\x08\x12\x12\n\nauthor_mid\x18\x05 \x01(\x03\x12\x14\n\x0csubtitle_url\x18\x06 \x01(\t\x12\x33\n\x06\x61uthor\x18\x07 \x01(\x0b\x32#.bilibili.web.interfaces.v1.AccInfo\"\xb0\x02\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x12\n\nhead_cover\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x15\n\rshort_content\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\r\n\x05state\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\x37\n\ttag_count\x18\n \x01(\x0b\x32$.bilibili.web.interfaces.v1.TagCount\x12\x10\n\x08is_atten\x18\x0b \x01(\x05\x12\r\n\x05likes\x18\x0c \x01(\x03\x12\r\n\x05hates\x18\r \x01(\x03\x12\x11\n\tattribute\x18\x0e \x01(\x05\x12\r\n\x05liked\x18\x0f \x01(\x05\x12\r\n\x05hated\x18\x10 \x01(\x05\"4\n\x08TagCount\x12\x0c\n\x04view\x18\x01 \x01(\x03\x12\x0b\n\x03use\x18\x02 \x01(\x03\x12\r\n\x05\x61tten\x18\x03 \x01(\x03\"\xa6\x01\n\x0bUGCPayAsset\x12\r\n\x05price\x18\x01 \x01(\x03\x12R\n\x0eplatform_price\x18\x02 \x03(\x0b\x32:.bilibili.web.interfaces.v1.UGCPayAsset.PlatformPriceEntry\x1a\x34\n\x12PlatformPriceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xa9\x02\n\tUGCSeason\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\r\n\x05intro\x18\x05 \x01(\t\x12\x12\n\nsign_state\x18\x06 \x01(\x05\x12\x11\n\tattribute\x18\x07 \x01(\x03\x12;\n\x08sections\x18\x08 \x03(\x0b\x32).bilibili.web.interfaces.v1.SeasonSection\x12\x34\n\x04stat\x18\t \x01(\x0b\x32&.bilibili.web.interfaces.v1.SeasonStat\x12\x10\n\x08\x65p_count\x18\n \x01(\x03\x12\x13\n\x0bseason_type\x18\x0b \x01(\x03\x12\x15\n\ris_pay_season\x18\x0c \x01(\x08\"\xa3\x03\n\x04View\x12,\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\x12\x10\n\x08no_cache\x18\x02 \x01(\x08\x12/\n\x05pages\x18\x03 \x03(\x0b\x32 .bilibili.web.interfaces.v1.Page\x12\x36\n\x08subtitle\x18\x04 \x01(\x0b\x32$.bilibili.web.interfaces.v1.Subtitle\x12\x36\n\x05\x61sset\x18\x05 \x01(\x0b\x32\'.bilibili.web.interfaces.v1.UGCPayAsset\x12\x34\n\x05label\x18\x06 \x01(\x0b\x32%.bilibili.web.interfaces.v1.ViewLabel\x12\x30\n\x05staff\x18\x07 \x03(\x0b\x32!.bilibili.web.interfaces.v1.Staff\x12\x39\n\nugc_season\x18\x08 \x01(\x0b\x32%.bilibili.web.interfaces.v1.UGCSeason\x12\x17\n\x0fstein_guide_cid\x18\t \x01(\x03\"\x87\x02\n\x0fViewDetailReply\x12.\n\x04view\x18\x01 \x01(\x0b\x32 .bilibili.web.interfaces.v1.View\x12.\n\x04\x63\x61rd\x18\x02 \x01(\x0b\x32 .bilibili.web.interfaces.v1.Card\x12-\n\x04tags\x18\x03 \x03(\x0b\x32\x1f.bilibili.web.interfaces.v1.Tag\x12\x33\n\x05reply\x18\x04 \x01(\x0b\x32$.bilibili.web.interfaces.v1.HotReply\x12\x30\n\x07related\x18\x05 \x03(\x0b\x32\x1f.bilibili.web.interfaces.v1.Arc\"*\n\rViewDetailReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\"\x19\n\tViewLabel\x12\x0c\n\x04type\x18\x01 \x01(\x03\"Q\n\x07VipInfo\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x14\n\x0cvip_pay_type\x18\x03 \x01(\x05\x12\x12\n\ntheme_type\x18\x04 \x01(\x05\"\x18\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t*F\n\x14\x41\x63tivitySeasonStatus\x12\x0e\n\nStatusNone\x10\x00\x12\x0e\n\nStatusLive\x10\x01\x12\x0e\n\nStatusView\x10\x02*R\n\tOrderType\x12\x0c\n\x08TypeNone\x10\x00\x12\x15\n\x11TypeOrderActivity\x10\x01\x12\x11\n\rTypeFavSeason\x10\x02\x12\r\n\tTypeClick\x10\x03*i\n\x12ReplyEmoteMetaSize\x12\x1f\n\x1b\x45MOTE_META_SIZE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45MOTE_META_SIZE_SMALL\x10\x01\x12\x17\n\x13\x45MOTE_META_SIZE_BIG\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.web.interfaces.v1.interfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTIVITYTHEME_KVCOLORENTRY._options = None
  _ACTIVITYTHEME_KVCOLORENTRY._serialized_options = b'8\001'
  _REPLYCONTENT_EMOTEENTRY._options = None
  _REPLYCONTENT_EMOTEENTRY._serialized_options = b'8\001'
  _UGCPAYASSET_PLATFORMPRICEENTRY._options = None
  _UGCPAYASSET_PLATFORMPRICEENTRY._serialized_options = b'8\001'
  _globals['_ACTIVITYSEASONSTATUS']._serialized_start=13677
  _globals['_ACTIVITYSEASONSTATUS']._serialized_end=13747
  _globals['_ORDERTYPE']._serialized_start=13749
  _globals['_ORDERTYPE']._serialized_end=13831
  _globals['_REPLYEMOTEMETASIZE']._serialized_start=13833
  _globals['_REPLYEMOTEMETASIZE']._serialized_end=13938
  _globals['_ACCINFO']._serialized_start=75
  _globals['_ACCINFO']._serialized_end=152
  _globals['_ACCOUNTCARD']._serialized_start=155
  _globals['_ACCOUNTCARD']._serialized_end=679
  _globals['_ACTIVITYARCHIVEREPLY']._serialized_start=682
  _globals['_ACTIVITYARCHIVEREPLY']._serialized_end=1053
  _globals['_ACTIVITYARCHIVEREQ']._serialized_start=1055
  _globals['_ACTIVITYARCHIVEREQ']._serialized_end=1124
  _globals['_ACTIVITYEPISODE']._serialized_start=1127
  _globals['_ACTIVITYEPISODE']._serialized_end=1330
  _globals['_ACTIVITYGAME']._serialized_start=1332
  _globals['_ACTIVITYGAME']._serialized_end=1455
  _globals['_ACTIVITYGAMEIFRAME']._serialized_start=1457
  _globals['_ACTIVITYGAMEIFRAME']._serialized_end=1506
  _globals['_ACTIVITYLIVE']._serialized_start=1509
  _globals['_ACTIVITYLIVE']._serialized_end=1879
  _globals['_ACTIVITYLIVETIMEINFOREPLY']._serialized_start=1882
  _globals['_ACTIVITYLIVETIMEINFOREPLY']._serialized_end=2025
  _globals['_ACTIVITYLIVETIMEINFOREQ']._serialized_start=2027
  _globals['_ACTIVITYLIVETIMEINFOREQ']._serialized_end=2074
  _globals['_ACTIVITYSEASONREPLY']._serialized_start=2077
  _globals['_ACTIVITYSEASONREPLY']._serialized_end=2471
  _globals['_ACTIVITYSEASONREQ']._serialized_start=2473
  _globals['_ACTIVITYSEASONREQ']._serialized_end=2541
  _globals['_ACTIVITYSEASONSECTION']._serialized_start=2543
  _globals['_ACTIVITYSEASONSECTION']._serialized_end=2670
  _globals['_ACTIVITYSUBSCRIBE']._serialized_start=2673
  _globals['_ACTIVITYSUBSCRIBE']._serialized_end=3123
  _globals['_ACTIVITYTHEME']._serialized_start=3126
  _globals['_ACTIVITYTHEME']._serialized_end=3925
  _globals['_ACTIVITYTHEME_KVCOLORENTRY']._serialized_start=3879
  _globals['_ACTIVITYTHEME_KVCOLORENTRY']._serialized_end=3925
  _globals['_ACTIVITYVIEW']._serialized_start=3928
  _globals['_ACTIVITYVIEW']._serialized_end=4360
  _globals['_ARC']._serialized_start=4363
  _globals['_ARC']._serialized_end=5148
  _globals['_AUTHOR']._serialized_start=5150
  _globals['_AUTHOR']._serialized_end=5199
  _globals['_CARD']._serialized_start=5202
  _globals['_CARD']._serialized_end=5396
  _globals['_CARDLEVELINFO']._serialized_start=5398
  _globals['_CARDLEVELINFO']._serialized_end=5474
  _globals['_CARDVIP']._serialized_start=5477
  _globals['_CARDVIP']._serialized_end=5608
  _globals['_CLICKACTIVITYSEASONREQ']._serialized_start=5611
  _globals['_CLICKACTIVITYSEASONREQ']._serialized_end=5958
  _globals['_DESCV2']._serialized_start=5960
  _globals['_DESCV2']._serialized_end=6016
  _globals['_DIMENSION']._serialized_start=6018
  _globals['_DIMENSION']._serialized_end=6076
  _globals['_FAVSEASONPARAM']._serialized_start=6078
  _globals['_FAVSEASONPARAM']._serialized_end=6113
  _globals['_HOTREPLY']._serialized_start=6115
  _globals['_HOTREPLY']._serialized_end=6230
  _globals['_JUMPURLPARAM']._serialized_start=6232
  _globals['_JUMPURLPARAM']._serialized_end=6264
  _globals['_LIVETIMELINE']._serialized_start=6266
  _globals['_LIVETIMELINE']._serialized_end=6383
  _globals['_NAMEPLATEINFO']._serialized_start=6385
  _globals['_NAMEPLATEINFO']._serialized_end=6497
  _globals['_NOREPLY']._serialized_start=6499
  _globals['_NOREPLY']._serialized_end=6508
  _globals['_OFFICIALINFO']._serialized_start=6510
  _globals['_OFFICIALINFO']._serialized_end=6567
  _globals['_OFFICIALVERIFY']._serialized_start=6569
  _globals['_OFFICIALVERIFY']._serialized_end=6613
  _globals['_OPERATIONRELATE']._serialized_start=6616
  _globals['_OPERATIONRELATE']._serialized_end=6769
  _globals['_PAGE']._serialized_start=6772
  _globals['_PAGE']._serialized_end=6953
  _globals['_PENDANTINFO']._serialized_start=6955
  _globals['_PENDANTINFO']._serialized_end=7026
  _globals['_REASONSTYLE']._serialized_start=7028
  _globals['_REASONSTYLE']._serialized_end=7055
  _globals['_RELATE']._serialized_start=7057
  _globals['_RELATE']._serialized_end=7146
  _globals['_RELATEITEM']._serialized_start=7148
  _globals['_RELATEITEM']._serialized_end=7188
  _globals['_RELATION']._serialized_start=7190
  _globals['_RELATION']._serialized_end=7236
  _globals['_REPLY']._serialized_start=7239
  _globals['_REPLY']._serialized_end=7974
  _globals['_REPLYCONTENT']._serialized_start=7977
  _globals['_REPLYCONTENT']._serialized_end=8367
  _globals['_REPLYCONTENT_EMOTEENTRY']._serialized_start=8283
  _globals['_REPLYCONTENT_EMOTEENTRY']._serialized_end=8367
  _globals['_REPLYEMOTE']._serialized_start=8370
  _globals['_REPLYEMOTE']._serialized_end=8572
  _globals['_REPLYEMOTEMETA']._serialized_start=8574
  _globals['_REPLYEMOTEMETA']._serialized_end=8652
  _globals['_REPLYFANSDETAIL']._serialized_start=8655
  _globals['_REPLYFANSDETAIL']._serialized_end=8805
  _globals['_REPLYFOLDER']._serialized_start=8807
  _globals['_REPLYFOLDER']._serialized_end=8873
  _globals['_REPLYLABEL']._serialized_start=8876
  _globals['_REPLYLABEL']._serialized_end=9049
  _globals['_REPLYLEVELINFO']._serialized_start=9051
  _globals['_REPLYLEVELINFO']._serialized_end=9128
  _globals['_REPLYMEMBER']._serialized_start=9131
  _globals['_REPLYMEMBER']._serialized_end=9288
  _globals['_REPLYMEMBERINFO']._serialized_start=9291
  _globals['_REPLYMEMBERINFO']._serialized_end=9732
  _globals['_REPLYPAGE']._serialized_start=9734
  _globals['_REPLYPAGE']._serialized_end=9803
  _globals['_REPLYUPACTION']._serialized_start=9805
  _globals['_REPLYUPACTION']._serialized_end=9849
  _globals['_REPLYVIP']._serialized_start=9852
  _globals['_REPLYVIP']._serialized_end=10055
  _globals['_REPLYVOTE']._serialized_start=10057
  _globals['_REPLYVOTE']._serialized_end=10139
  _globals['_REQUSER']._serialized_start=10141
  _globals['_REQUSER']._serialized_end=10217
  _globals['_RESERVEACTIVITYPARAM']._serialized_start=10219
  _globals['_RESERVEACTIVITYPARAM']._serialized_end=10302
  _globals['_RIGHTS']._serialized_start=10305
  _globals['_RIGHTS']._serialized_end=10539
  _globals['_SEASONEPISODE']._serialized_start=10542
  _globals['_SEASONEPISODE']._serialized_end=10838
  _globals['_SEASONSECTION']._serialized_start=10841
  _globals['_SEASONSECTION']._serialized_end=10977
  _globals['_SEASONSTAT']._serialized_start=10980
  _globals['_SEASONSTAT']._serialized_end=11149
  _globals['_SPACE']._serialized_start=11151
  _globals['_SPACE']._serialized_end=11188
  _globals['_STAFF']._serialized_start=11191
  _globals['_STAFF']._serialized_end=11459
  _globals['_STAFFINFO']._serialized_start=11461
  _globals['_STAFFINFO']._serialized_end=11500
  _globals['_STAT']._serialized_start=11503
  _globals['_STAT']._serialized_end=11716
  _globals['_SUBTITLE']._serialized_start=11718
  _globals['_SUBTITLE']._serialized_end=11806
  _globals['_SUBTITLEITEM']._serialized_start=11809
  _globals['_SUBTITLEITEM']._serialized_end=11977
  _globals['_TAG']._serialized_start=11980
  _globals['_TAG']._serialized_end=12284
  _globals['_TAGCOUNT']._serialized_start=12286
  _globals['_TAGCOUNT']._serialized_end=12338
  _globals['_UGCPAYASSET']._serialized_start=12341
  _globals['_UGCPAYASSET']._serialized_end=12507
  _globals['_UGCPAYASSET_PLATFORMPRICEENTRY']._serialized_start=12455
  _globals['_UGCPAYASSET_PLATFORMPRICEENTRY']._serialized_end=12507
  _globals['_UGCSEASON']._serialized_start=12510
  _globals['_UGCSEASON']._serialized_end=12807
  _globals['_VIEW']._serialized_start=12810
  _globals['_VIEW']._serialized_end=13229
  _globals['_VIEWDETAILREPLY']._serialized_start=13232
  _globals['_VIEWDETAILREPLY']._serialized_end=13495
  _globals['_VIEWDETAILREQ']._serialized_start=13497
  _globals['_VIEWDETAILREQ']._serialized_end=13539
  _globals['_VIEWLABEL']._serialized_start=13541
  _globals['_VIEWLABEL']._serialized_end=13566
  _globals['_VIPINFO']._serialized_start=13568
  _globals['_VIPINFO']._serialized_end=13649
  _globals['_VIPLABEL']._serialized_start=13651
  _globals['_VIPLABEL']._serialized_end=13675
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pagination/pagination.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/pagination/pagination.proto\x12\x13\x62ilibili.pagination\"G\n\x0e\x46\x65\x65\x64Pagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x12\n\nis_refresh\x18\x03 \x01(\x08\"Y\n\x13\x46\x65\x65\x64PaginationReply\x12\x13\n\x0bnext_offset\x18\x01 \x01(\t\x12\x13\n\x0bprev_offset\x18\x02 \x01(\t\x12\x18\n\x10last_read_offset\x18\x03 \x01(\t\"-\n\nPagination\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x0c\n\x04next\x18\x02 \x01(\t\"-\n\x0fPaginationReply\x12\x0c\n\x04next\x18\x01 \x01(\t\x12\x0c\n\x04prev\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pagination.pagination_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FEEDPAGINATION']._serialized_start=61
  _globals['_FEEDPAGINATION']._serialized_end=132
  _globals['_FEEDPAGINATIONREPLY']._serialized_start=134
  _globals['_FEEDPAGINATIONREPLY']._serialized_end=223
  _globals['_PAGINATION']._serialized_start=225
  _globals['_PAGINATION']._serialized_end=270
  _globals['_PAGINATIONREPLY']._serialized_start=272
  _globals['_PAGINATIONREPLY']._serialized_end=317
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.show.popular.v1 import popular_pb2 as bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2


class PopularStub(object):
    """热门
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Index = channel.unary_unary(
                '/bilibili.app.show.v1.Popular/Index',
                request_serializer=bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2.PopularResultReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2.PopularReply.FromString,
                )


class PopularServicer(object):
    """热门
    """

    def Index(self, request, context):
        """热门列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PopularServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Index': grpc.unary_unary_rpc_method_handler(
                    servicer.Index,
                    request_deserializer=bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2.PopularResultReq.FromString,
                    response_serializer=bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2.PopularReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.show.v1.Popular', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Popular(object):
    """热门
    """

    @staticmethod
    def Index(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.show.v1.Popular/Index',
            bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2.PopularResultReq.SerializeToString,
            bilibili_dot_app_dot_show_dot_popular_dot_v1_dot_popular__pb2.PopularReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/click/v1/heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/click/v1/heartbeat.proto\x12\x15\x62ilibili.app.click.v1\"\x1a\n\x0b\x41\x63\x63ountInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x04\"=\n\x07\x41ppInfo\x12\x16\n\x0etop_page_class\x18\x01 \x01(\t\x12\r\n\x05\x66time\x18\x02 \x01(\x03\x12\x0b\n\x03\x64id\x18\x03 \x01(\t\"\'\n\x05\x45xtra\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\r\n\x05refer\x18\x02 \x01(\t\"\x10\n\x0eHeartBeatReply\"\xec\x03\n\x0cHeartBeatReq\x12\x12\n\nsession_v2\x18\x01 \x01(\t\x12+\n\x05stage\x18\x02 \x01(\x0e\x32\x1c.bilibili.app.click.v1.Stage\x12\x16\n\x0estream_timeout\x18\x03 \x01(\x04\x12\x17\n\x0f\x62\x61tch_frequency\x18\x04 \x01(\x04\x12\x11\n\tfrequency\x18\x05 \x01(\x02\x12\x34\n\nvideo_meta\x18\x06 \x01(\x0b\x32 .bilibili.app.click.v1.VideoMeta\x12\x30\n\x08\x61pp_info\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.click.v1.AppInfo\x12\x38\n\x0c\x61\x63\x63ount_info\x18\x08 \x01(\x0b\x32\".bilibili.app.click.v1.AccountInfo\x12\x43\n\x12pre_process_result\x18\t \x01(\x0b\x32\'.bilibili.app.click.v1.PreProcessResult\x12:\n\rplayer_status\x18\n \x03(\x0b\x32#.bilibili.app.click.v1.PlayerStatus\x12\x34\n\nvideo_info\x18\x0b \x01(\x0b\x32 .bilibili.app.click.v1.VideoInfo\"\x83\x01\n\x0cPlayerStatus\x12\x15\n\rplayback_rate\x18\x01 \x01(\x02\x12\x10\n\x08progress\x18\x02 \x01(\x04\x12\x34\n\nplay_state\x18\x03 \x01(\x0e\x32 .bilibili.app.click.v1.PlayState\x12\x14\n\x0cis_buffering\x18\x04 \x01(\x08\"\x1e\n\x10PreProcessResult\x12\n\n\x02vt\x18\x01 \x01(\x03\"!\n\tVideoInfo\x12\x14\n\x0c\x63id_duration\x18\x01 \x01(\x04\"%\n\tVideoMeta\x12\x0b\n\x03\x61id\x18\x01 \x01(\x04\x12\x0b\n\x03\x63id\x18\x02 \x01(\x04*m\n\tPlayState\x12\x11\n\rSTATE_UNKNOWN\x10\x00\x12\r\n\tPREPARING\x10\x01\x12\x0c\n\x08PREPARED\x10\x02\x12\x0b\n\x07PLAYING\x10\x03\x12\n\n\x06PAUSED\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06*:\n\x05Stage\x12\x11\n\rSTAGE_UNKNOWN\x10\x00\x12\t\n\x05START\x10\x01\x12\x07\n\x03\x45ND\x10\x02\x12\n\n\x06SAMPLE\x10\x03\x32\x07\n\x05\x43lickb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.click.v1.heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PLAYSTATE']._serialized_start=949
  _globals['_PLAYSTATE']._serialized_end=1058
  _globals['_STAGE']._serialized_start=1060
  _globals['_STAGE']._serialized_end=1118
  _globals['_ACCOUNTINFO']._serialized_start=64
  _globals['_ACCOUNTINFO']._serialized_end=90
  _globals['_APPINFO']._serialized_start=92
  _globals['_APPINFO']._serialized_end=153
  _globals['_EXTRA']._serialized_start=155
  _globals['_EXTRA']._serialized_end=194
  _globals['_HEARTBEATREPLY']._serialized_start=196
  _globals['_HEARTBEATREPLY']._serialized_end=212
  _globals['_HEARTBEATREQ']._serialized_start=215
  _globals['_HEARTBEATREQ']._serialized_end=707
  _globals['_PLAYERSTATUS']._serialized_start=710
  _globals['_PLAYERSTATUS']._serialized_end=841
  _globals['_PREPROCESSRESULT']._serialized_start=843
  _globals['_PREPROCESSRESULT']._serialized_end=873
  _globals['_VIDEOINFO']._serialized_start=875
  _globals['_VIDEOINFO']._serialized_end=908
  _globals['_VIDEOMETA']._serialized_start=910
  _globals['_VIDEOMETA']._serialized_end=947
  _globals['_CLICK']._serialized_start=1120
  _globals['_CLICK']._serialized_end=1127
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Status(google.protobuf.message.Message):
    """响应gRPC Status
    当status code是[UNKNOWN = 2]时，details为业务详细的错误信息，进行proto any转换成业务码结构体
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    code: builtins.int
    """业务错误码"""
    message: builtins.str
    """业务错误信息"""
    @property
    def details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """扩展信息嵌套(相当于该messasge的套娃)"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
        details: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "details", b"details", "message", b"message"]) -> None: ...

global___Status = Status



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PremiereStatusReq(google.protobuf.message.Message):
    """获取首播状态-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EP_ID_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """剧集epid"""
    def __init__(
        self,
        *,
        ep_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ep_id", b"ep_id"]) -> None: ...

global___PremiereStatusReq = PremiereStatusReq

@typing_extensions.final
class PremiereStatusReply(google.protobuf.message.Message):
    """获取首播状态-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    DELAY_TIME_FIELD_NUMBER: builtins.int
    ONLINE_COUNT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    AFTER_PREMIERE_TYPE_FIELD_NUMBER: builtins.int
    progress: builtins.int
    """服务端播放进度 单位ms 用户实际播放进度：progress - delay_time"""
    start_time: builtins.int
    """起播时间戳 单位ms"""
    delay_time: builtins.int
    """延迟播放时长 单位ms"""
    online_count: builtins.int
    """首播在线人数"""
    status: builtins.int
    """首播状态
    1:预热 2:首播中 3:紧急停播 4:已结束
    """
    after_premiere_type: builtins.int
    """首播结束后跳转类型
    1:下架 2:转点播
    """
    def __init__(
        self,
        *,
        progress: builtins.int = ...,
        start_time: builtins.int = ...,
        delay_time: builtins.int = ...,
        online_count: builtins.int = ...,
        status: builtins.int = ...,
        after_premiere_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_premiere_type", b"after_premiere_type", "delay_time", b"delay_time", "online_count", b"online_count", "progress", b"progress", "start_time", b"start_time", "status", b"status"]) -> None: ...

global___PremiereStatusReply = PremiereStatusReply



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ModResourceResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATCION_FIELD_NUMBER: builtins.int
    APP_KEY_FIELD_NUMBER: builtins.int
    POOL_NAME_FIELD_NUMBER: builtins.int
    MODULE_NAME_FIELD_NUMBER: builtins.int
    MODULE_VERSION_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    atcion: builtins.int
    """"""
    app_key: builtins.str
    """"""
    pool_name: builtins.str
    """"""
    module_name: builtins.str
    """"""
    module_version: builtins.int
    """"""
    list_version: builtins.int
    """"""
    def __init__(
        self,
        *,
        atcion: builtins.int = ...,
        app_key: builtins.str = ...,
        pool_name: builtins.str = ...,
        module_name: builtins.str = ...,
        module_version: builtins.int = ...,
        list_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_key", b"app_key", "atcion", b"atcion", "list_version", b"list_version", "module_name", b"module_name", "module_version", b"module_version", "pool_name", b"pool_name"]) -> None: ...

global___ModResourceResp = ModResourceResp
